pub struct BKNeuron {}Expand description
BK channel neuron — WB base + voltage- and Ca2+-dependent K+ current.
BK (big conductance, MaxiK) channels are activated by both membrane depolarisation and intracellular Ca2+. They have the largest single- channel conductance (~250 pS) of any K+ channel. During action potentials, Ca2+ influx through voltage-gated Ca2+ channels activates BK, producing fast repolarisation and a prominent fast AHP.
Key mechanism for:
- Fast afterhyperpolarisation (fAHP): rapid spike repolarisation
- Action potential narrowing: BK shortens AP duration
- Burst termination: accumulated Ca2+ activates BK, ending burst
- High-frequency firing: fast repolarisation enables rapid recovery
Bhatt & Storm, J Physiol 557:329, 2003; Faber & Bhatt, PNAS 100:2813, 2003.
Fields
v: f64h: f64n: f64ca: f64g_na: f64g_k: f64g_bk: f64g_l: f64e_na: f64e_k: f64e_l: f64c_m: f64phi: f64tau_ca: f64dt: f64v_threshold: f64gain: f64Implementations